<?php
/**
 * BSS Commerce Co.
 *
 * NOTICE OF LICENSE
 *
 * @category   BSS
 * @package    Bss_InventoryReport
 * @author     Extension Team
 * @copyright  Copyright (c) 2018-2019 BSS Commerce Co. ( http://bsscommerce.com )
 * @license    http://bsscommerce.com/Bss-Commerce-License.txt
 */
namespace Bss\InventoryReport\Api\Data;

interface InventoryInterface
{
    /**
     * Constants for keys of data array. Identical to the name of the getter in snake case
     */
    const REPORT_ID = 'report_id';
    const PRODUCT_ID = 'product_id';
    const CREATE_TIME = 'time';
    const QUANTITY_AFTER = 'qty_after';
    const STOCK_STATUS = 'stock_status';
    const NOTE = 'note';
    const USER = 'user';
    const PRODUCT_NAME = 'product_name';
    const PRODUCT_SKU = 'product_sku';
    const QUANTITY_CHANGE = 'qty_change';
    const SHIPMENT_ENTITY_ID = 'shipment_entity_id';
    const CREDIT_ENTITY_ID = 'credit_entity_id';
    const SOURCE_CODE = 'source_code';
    const SALEABLE_QTY = 'saleable_qty';
    const SALEABLE_QTY_CHANGE = 'saleable_qty_change';
    const ORDER_ENTITY_ID = 'order_entity_id';

    /**
     * Get Report ID
     *
     * @return int
     */
    public function getReportId();

    /**
     * Get Product ID
     *
     * @return string
     */
    public function getProductId();

    /**
     * Get Time
     *
     * @return string
     */
    public function getTime();

    /**
     * Get Qty After
     *
     * @return string
     */
    public function getQtyAfter();

    /**
     * Get Stock Status
     *
     * @return string
     */
    public function getStockStatus();

    /**
     * Get Note
     *
     * @return int
     */
    public function getNote();

    /**
     * Get User
     *
     * @return string
     */
    public function getUser();

    /**
     * Set product name
     *
     * @return void
     */
    public function getProductName();

    /**
     * Set product sku
     *
     * @return void
     */
    public function getProductSku();

    /**
     * Get Quantity Change
     *
     * @return mixed
     */
    public function getQtyChange();

    /**
     * Set shipment entity id
     *
     * @return void
     */
    public function getShipmentEntityId();

    /**
     * Get creadit entity id
     *
     * @return void
     */
    public function getCreditEntityId();

    /**
     * Get source code
     *
     * @return string
     */
    public function getSourceCode();

    /**
     * Get saleable qty
     *
     * @return float
     */
    public function getSaleableQty();

    /**
     * Get saleable qty change
     *
     * @return float
     */
    public function getSaleableQtyChange();

    /**
     * Get order entity id
     *
     * @return int
     */
    public function getOrderEntityId();

    /**
     * Set report id
     *
     * @param string $reportId
     * @return $this
     */
    public function setReportId($reportId);

    /**
     * Set Product ID
     *
     * @param string $productId
     * @return $this
     */
    public function setProductId($productId);

    /**
     * Set Time
     *
     * @param string $time
     * @return $this
     */
    public function setTime($time);

    /**
     * Set Quantity After
     *
     * @param float $qtyAfter
     * @return $this
     */
    public function setQtyAfter($qtyAfter);

    /**
     * Set Stock Status
     *
     * @param int $status
     * @return $this
     */
    public function setStockStatus($status);

    /**
     * Set Note
     *
     * @param string $note
     * @return $this
     */
    public function setNote($note);

    /**
     * Set User
     *
     * @param string $userName
     * @return $this
     */
    public function setUser($userName);

    /**
     * Set product name
     *
     * @param string $productName
     * @return $this
     */
    public function setProductName($productName);

    /**
     * Set product sku
     *
     * @param string $sku
     * @return $this
     */
    public function setProductSku($sku);

    /**
     * Get Quantity Change
     *
     * @param float $qty
     * @return $this
     */
    public function setQtyChange($qty);

    /**
     * Set shipment entity id
     *
     * @param int $entityId
     * @return $this
     */
    public function setShipmentEntityId($entityId);

    /**
     * Get creadit entity id
     *
     * @param int $entityId
     * @return $this
     */
    public function setCreditEntityId($entityId);

    /**
     * Set source code
     *
     * @param string $sourceCode
     * @return $this
     */
    public function setSourceCode($sourceCode);

    /**
     * Set saleable qty
     *
     * @param float $qty
     * @return $this
     */
    public function setSaleableQty($qty);

    /**
     * Set source code
     *
     * @param float $qty
     * @return $this
     */
    public function setSaleableQtyChange($qty);

    /**
     * Set source code
     *
     * @param int $id
     * @return $this
     */
    public function setOrderEntityId($id);
}
