<?php
/**
 * BSS Commerce Co.
 *
 * NOTICE OF LICENSE
 *
 * @category   BSS
 * @package    Bss_InventoryReport
 * @author     Extension Team
 * @copyright  Copyright (c) 2018-2019 BSS Commerce Co. ( http://bsscommerce.com )
 * @license    http://bsscommerce.com/Bss-Commerce-License.txt
 */
namespace Bss\InventoryReport\Api;

use Bss\InventoryReport\Api\Data\InventoryInterface;
use Magento\Framework\Api\SearchCriteriaInterface;

interface InventoryRepositoryInterface
{
    /**
     * Save Inventory.
     *
     * @param InventoryInterface $inventory
     * @return InventoryInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function save(InventoryInterface $inventory);

    /**
     * Retrieve Inventory.
     *
     * @param int $reportId
     * @return InventoryInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function getById($reportId);

    /**
     * Delete Inventory Report.
     *
     * @param InventoryInterface $inventory
     * @return bool true on success
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function delete(InventoryInterface $inventory);

    /**
     * Delete Inventory Report by ID.
     *
     * @param int $notificationId
     * @return bool true on success
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function deleteById($notificationId);

    /**
     * Get list items
     *
     * @param SearchCriteriaInterface $searchCriteria
     * @return \Bss\InventoryReport\Api\Data\InventorySearchResultsInterface
     */
    public function getList(SearchCriteriaInterface $searchCriteria);
}
