<?php
/**
 * BSS Commerce Co.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the EULA
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://bsscommerce.com/Bss-Commerce-License.txt
 *
 * @category   BSS
 * @package    Bss_InventoryReport
 * @author     Extension Team
 * @copyright  Copyright (c) 2017-2018 BSS Commerce Co. ( http://bsscommerce.com )
 * @license    http://bsscommerce.com/Bss-Commerce-License.txt
 */

namespace Bss\InventoryReport\Helper;

use Magento\Backend\Model\Auth\Session as AdminSession;
use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Store\Model\ScopeInterface;

class InventoryData extends AbstractHelper
{
    /**
     * Const
     */
    const PATH_XML_BACKORDERS = 'cataloginventory/item_options/backorders';
    const PATH_XML_MIN_QTY = 'cataloginventory/item_options/min_qty';

    /**
     * @var AdminSession
     */
    protected $adminSession;

    /**
     * InventoryData constructor.
     * @param AdminSession $adminSession
     * @param Context $context
     */
    public function __construct(
        AdminSession $adminSession,
        Context $context
    ) {
        $this->adminSession = $adminSession;
        parent::__construct($context);
    }

    /**
     * @return string|int
     */
    public function getBackOrderValue()
    {
        return $this->scopeConfig->getValue(
            self::PATH_XML_BACKORDERS,
            ScopeInterface::SCOPE_STORE
        );
    }

    /**
     * @return string|int
     */
    public function getThresholdValue()
    {
        return $this->scopeConfig->getValue(
            self::PATH_XML_MIN_QTY,
            ScopeInterface::SCOPE_STORE
        );
    }

    /**
     * @return string
     */
    public function getAdminName()
    {
        $adminUser = __('Administrator');
        if ($this->adminSession->getUser()) {
            // Fix generate fixtures
            // Reason: Generate fixtures does not admin session
            $adminUser = $this->adminSession->getUser()->getUserName();
        }
        return __('Admin') . '/' . $adminUser;
    }
}
