<?php
/**
 * BSS Commerce Co.
 *
 * NOTICE OF LICENSE
 *
 * @category   BSS
 * @package    Bss_InventoryReport
 * @author     Extension Team
 * @copyright  Copyright (c) 2018-2019 BSS Commerce Co. ( http://bsscommerce.com )
 * @license    http://bsscommerce.com/Bss-Commerce-License.txt
 */
namespace Bss\InventoryReport\Model\MultiInventorySource;

use Magento\Framework\ObjectManagerInterface;
use Magento\Framework\Module\Manager;

class MsiObjectManagement
{
    /**
     * Const
     */
    const MSI_MODULE_CORE = 'Magento_Inventory';

    /**
     * @var ObjectManagerInterface
     */
    protected $objectManagerFactory;

    /**
     * @var Manager
     */
    protected $moduleManager;

    /**
     * @var null
     */
    protected $stockModel;

    /**
     * @var null
     */
    protected $sourceModel;

    /**
     * @var null
     */
    protected $sourceItem;

    /**
     * @var null
     */
    protected $sourceItemRepository;

    /**
     * @var null
     */
    protected $getSourceItemsBySku;

    /**
     * @var null
     */
    protected $getReservationsQuantity;

    /**
     * @var null
     */
    protected $stockSourceLinkFactory;

    /**
     * @var null
     */
    protected $getSalableQuantityDataBySku;

    /**
     * @var null
     */
    protected $getStockSourceLinksBySourceCode;

    /**
     * @var null
     */
    protected $salesChannel;

    /**
     * @var null
     */
    protected $getProductSalableQty;

    /**
     * @var null
     */
    protected $stockResolver;

    /**
     * @var null
     */
    protected $defaultSourceProvider;

    /**
     * @var null
     */
    protected $isSingleSourceMode;

    /**
     * @var null
     */
    protected $getItemsToDeductFromShipment;

    /**
     * @var null
     */
    protected $getSourceDeductedOrderItems;

    /**
     * @var null
     */
    protected $getProductTypesBySkus;

    /**
     * @var null
     */
    protected $isSourceItemManagementAllowedForProductType;

    /**
     * MsiObjectManagement constructor.
     * @param ObjectManagerInterface $objectManagerFactory
     * @param Manager $moduleManager
     * @param null $stockModel
     * @param null $sourceModel
     * @param null $sourceItem
     * @param null $sourceItemRepository
     * @param null $getSourceItemsBySku
     * @param null $getReservationsQuantity
     * @param null $stockSourceLinkFactory
     * @param null $getSalableQuantityDataBySku
     * @param null $getStockSourceLinksBySourceCode
     * @param null $salesChannel
     * @param null $getProductSalableQty
     * @param null $stockResolver
     * @param null $defaultSourceProvider
     * @param null $isSingleSourceMode
     * @param null $getItemsToDeductFromShipment
     * @param null $getSourceDeductedOrderItems
     * @param null $getProductTypesBySkus
     * @param null $isSourceItemManagementAllowedForProductType
     */
    public function __construct(
        ObjectManagerInterface $objectManagerFactory,
        Manager $moduleManager,
        $stockModel = null,
        $sourceModel = null,
        $sourceItem = null,
        $sourceItemRepository = null,
        $getSourceItemsBySku = null,
        $getReservationsQuantity = null,
        $stockSourceLinkFactory = null,
        $getSalableQuantityDataBySku = null,
        $getStockSourceLinksBySourceCode = null,
        $salesChannel = null,
        $getProductSalableQty = null,
        $stockResolver = null,
        $defaultSourceProvider = null,
        $isSingleSourceMode = null,
        $getItemsToDeductFromShipment = null,
        $getSourceDeductedOrderItems = null,
        $getProductTypesBySkus = null,
        $isSourceItemManagementAllowedForProductType = null
    ) {
        $this->objectManagerFactory = $objectManagerFactory;
        $this->moduleManager = $moduleManager;
        $this->stockModel = $stockModel;
        $this->sourceModel = $sourceModel;
        $this->sourceItem = $sourceItem;
        $this->sourceItemRepository = $sourceItemRepository;
        $this->getSourceItemsBySku = $getSourceItemsBySku;
        $this->getReservationsQuantity = $getReservationsQuantity;
        $this->stockSourceLinkFactory = $stockSourceLinkFactory;
        $this->getSalableQuantityDataBySku = $getSalableQuantityDataBySku;
        $this->getStockSourceLinksBySourceCode = $getStockSourceLinksBySourceCode;
        $this->salesChannel = $salesChannel;
        $this->getProductSalableQty = $getProductSalableQty;
        $this->stockResolver = $stockResolver;
        $this->defaultSourceProvider = $defaultSourceProvider;
        $this->isSingleSourceMode = $isSingleSourceMode;
        $this->getItemsToDeductFromShipment = $getItemsToDeductFromShipment;
        $this->getSourceDeductedOrderItems = $getSourceDeductedOrderItems;
        $this->getProductTypesBySkus = $getProductTypesBySkus;
        $this->isSourceItemManagementAllowedForProductType = $isSourceItemManagementAllowedForProductType;
    }

    /**
     * @return bool
     */
    public function isMsiEnabled()
    {
        return $this->moduleManager->isEnabled(self::MSI_MODULE_CORE);
    }

    /**
     * @param $objectName
     * @param array $data
     * @return object|null
     */
    public function getObjectInstance($objectName, $data = [])
    {
        if ($this->isMsiEnabled()) {
            return $this->objectManagerFactory->create(
                $objectName,
                $data
            );
        }
        return null;
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getStockModel($data = [])
    {
        return $this->getObjectInstance(
            $this->stockModel,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getSourceModel($data = [])
    {
        return $this->getObjectInstance(
            $this->sourceModel,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getSourceItem($data = [])
    {
        return $this->getObjectInstance(
            $this->sourceItem,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getSourceItemRepository($data = [])
    {
        return $this->getObjectInstance(
            $this->sourceItemRepository,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getSourceItemsBySku($data = [])
    {
        return $this->getObjectInstance(
            $this->getSourceItemsBySku,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getReservationsQuantity($data = [])
    {
        return $this->getObjectInstance(
            $this->getReservationsQuantity,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getStockSourceLinkFactory($data = [])
    {
        return $this->getObjectInstance(
            $this->stockSourceLinkFactory,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getSalableQuantityDataBySku($data = [])
    {
        return $this->getObjectInstance(
            $this->getSalableQuantityDataBySku,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getStockSourceLinksBySourceCode($data = [])
    {
        return $this->getObjectInstance(
            $this->getStockSourceLinksBySourceCode,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getSalesChannel($data = [])
    {
        return $this->getObjectInstance(
            $this->salesChannel,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getProductSalableQty($data = [])
    {
        return $this->getObjectInstance(
            $this->getProductSalableQty,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getStockResolver($data = [])
    {
        return $this->getObjectInstance(
            $this->stockResolver,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getDefaultSourceProvider($data = [])
    {
        return $this->getObjectInstance(
            $this->defaultSourceProvider,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getIsSingleSourceMode($data = [])
    {
        return $this->getObjectInstance(
            $this->isSingleSourceMode,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getItemsToDeductFromShipment($data = [])
    {
        return $this->getObjectInstance(
            $this->getItemsToDeductFromShipment,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getSourceDeductedOrderItems($data = [])
    {
        return $this->getObjectInstance(
            $this->getSourceDeductedOrderItems,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getProductTypesBySkus($data = [])
    {
        return $this->getObjectInstance(
            $this->getProductTypesBySkus,
            $data
        );
    }

    /**
     * @param array $data
     * @return object|null
     */
    public function getIsSourceItemManagementAllowedForProductType($data = [])
    {
        return $this->getObjectInstance(
            $this->isSourceItemManagementAllowedForProductType,
            $data
        );
    }
}
