<?php
/**
 * BSS Commerce Co.
 *
 * NOTICE OF LICENSE
 *
 * @category   BSS
 * @package    Bss_InventoryReport
 * @author     Extension Team
 * @copyright  Copyright (c) 2018-2019 BSS Commerce Co. ( http://bsscommerce.com )
 * @license    http://bsscommerce.com/Bss-Commerce-License.txt
 */
namespace Bss\InventoryReport\Model;

use Bss\InventoryReport\Api\Data\InventoryInterface;
use Magento\Framework\Model\AbstractModel;

class Report extends AbstractModel implements InventoryInterface
{
    /**
     * { @inheritdoc }
     */
    public function _construct()
    {
        $this->_init(\Bss\InventoryReport\Model\ResourceModel\Report::class);
    }

    /**
     * Get Report Id
     *
     * @return int
     */
    public function getReportId()
    {
        return $this->getData(InventoryInterface::REPORT_ID);
    }

    /**
     * Get Product ID
     *
     * @return string
     */
    public function getProductId()
    {
        return $this->getData(InventoryInterface::PRODUCT_ID);
    }

    /**
     * Get Qty After
     *
     * @return string
     */
    public function getQtyAfter()
    {
        return $this->getData(InventoryInterface::QUANTITY_AFTER);
    }

    /**
     * Get cate create time
     *
     * @return string
     */
    public function getTime()
    {
        return $this->getData(InventoryInterface::CREATE_TIME);
    }

    /**
     * Get Stock Status
     *
     * @return string
     */
    public function getStockStatus()
    {
        return $this->getData(InventoryInterface::STOCK_STATUS);
    }

    /**
     * Get Note
     *
     * @return int
     */
    public function getNote()
    {
        return $this->getData(InventoryInterface::NOTE);
    }

    /**
     * Get User
     *
     * @return string
     */
    public function getUser()
    {
        return $this->getData(InventoryInterface::USER);
    }

    /**
     * Get product name
     *
     * @param int $id
     * @return void
     */
    public function getProductName()
    {
        return $this->getData(InventoryInterface::PRODUCT_NAME);
    }

    /**
     * Get product sku
     *
     * @return void
     */
    public function getProductSku()
    {
        return $this->getData(InventoryInterface::PRODUCT_SKU);
    }

    /**
     * Get Quantity Change
     *
     * @return mixed
     */
    public function getQtyChange()
    {
        return $this->getData(InventoryInterface::QUANTITY_CHANGE);
    }

    /**
     * Get shipment entity id
     *
     * @return void
     */
    public function getShipmentEntityId()
    {
        return $this->getData(InventoryInterface::SHIPMENT_ENTITY_ID);
    }

    /**
     * Get creadit entity id
     *
     * @return void
     */
    public function getCreditEntityId()
    {
        return $this->getData(InventoryInterface::CREDIT_ENTITY_ID);
    }

    /**
     * Get source code
     *
     * @return string
     */
    public function getSourceCode()
    {
        return $this->getData(InventoryInterface::SOURCE_CODE);
    }

    /**
     * Get saleable qty
     *
     * @return float
     */
    public function getSaleableQty()
    {
        return $this->getData(InventoryInterface::SALEABLE_QTY);
    }

    /**
     * Get saleable qty change
     *
     * @return float
     */
    public function getSaleableQtyChange()
    {
        return $this->getData(InventoryInterface::SALEABLE_QTY_CHANGE);
    }

    /**
     * Get order entity id
     *
     * @return int
     */
    public function getOrderEntityId()
    {
        return $this->getData(InventoryInterface::ORDER_ENTITY_ID);
    }

    /**
     * Set report id
     *
     * @param string $reportId
     * @return Report
     */
    public function setReportId($reportId)
    {
        return $this->setData(InventoryInterface::CREATE_TIME, $reportId);
    }

    /**
     * Set Product ID
     *
     * @param string $productId
     * @return Report
     */
    public function setProductId($productId)
    {
        return $this->setData(InventoryInterface::PRODUCT_ID, $productId);
    }

    /**
     * Set Time
     *
     * @param string $time
     * @return Report
     */
    public function setTime($time)
    {
        return $this->setData(InventoryInterface::CREATE_TIME, $time);
    }

    /**
     * Set Quantity After
     *
     * @param float $qtyAfter
     * @return Report
     */
    public function setQtyAfter($qtyAfter)
    {
        return $this->setData(InventoryInterface::QUANTITY_AFTER, $qtyAfter);
    }

    /**
     * Set Stock Status
     *
     * @param int $status
     * @return Report
     */
    public function setStockStatus($status)
    {
        return $this->setData(InventoryInterface::STOCK_STATUS, $status);
    }

    /**
     * Set Note
     *
     * @param string $note
     * @return Report
     */
    public function setNote($note)
    {
        return $this->setData(InventoryInterface::NOTE, $note);
    }

    /**
     * Set User
     *
     * @param string $userName
     * @return Report
     */
    public function setUser($userName)
    {
        return $this->setData(InventoryInterface::USER, $userName);
    }

    /**
     * Set product name
     *
     * @param string $productName
     * @return Report
     */
    public function setProductName($productName)
    {
        return $this->setData(InventoryInterface::PRODUCT_NAME, $productName);
    }

    /**
     * Set product sku
     *
     * @param string $sku
     * @return Report
     */
    public function setProductSku($sku)
    {
        return $this->setData(InventoryInterface::PRODUCT_SKU, $sku);
    }

    /**
     * Get Quantity Change
     *
     * @param float $qty
     * @return Report
     */
    public function setQtyChange($qty)
    {
        return $this->setData(InventoryInterface::QUANTITY_CHANGE, $qty);
    }

    /**
     * Set shipment entity id
     *
     * @param int $entityId
     * @return Report
     */
    public function setShipmentEntityId($entityId)
    {
        return $this->setData(InventoryInterface::SHIPMENT_ENTITY_ID, $entityId);
    }

    /**
     * Set creadit entity id
     *
     * @param int $entityId
     * @return Report
     */
    public function setCreditEntityId($entityId)
    {
        return $this->setData(InventoryInterface::CREDIT_ENTITY_ID, $entityId);
    }

    /**
     * Set creadit entity id
     *
     * @param int $sourceCode
     * @return Report
     */
    public function setSourceCode($sourceCode)
    {
        return $this->setData(InventoryInterface::SOURCE_CODE, $sourceCode);
    }

    /**
     * Set saleable qty
     *
     * @param float $qty
     * @return Report
     */
    public function setSaleableQty($qty)
    {
        return $this->setData(InventoryInterface::SALEABLE_QTY, $qty);
    }

    /**
     * Set source code
     *
     * @param float $qty
     * @return Report
     */
    public function setSaleableQtyChange($qty)
    {
        return $this->setData(InventoryInterface::SALEABLE_QTY_CHANGE, $qty);
    }

    /**
     * Set source code
     *
     * @param int $id
     * @return Report
     */
    public function setOrderEntityId($id)
    {
        return $this->setData(InventoryInterface::ORDER_ENTITY_ID, $id);
    }
}
