<?php
/**
 * BSS Commerce Co.
 *
 * NOTICE OF LICENSE
 *
 * @category   BSS
 * @package    Bss_InventoryReport
 * @author     Extension Team
 * @copyright  Copyright (c) 2018-2019 BSS Commerce Co. ( http://bsscommerce.com )
 * @license    http://bsscommerce.com/Bss-Commerce-License.txt
 */
namespace Bss\InventoryReport\Model\ResourceModel;

use Magento\Framework\Model\ResourceModel\Db\AbstractDb;

class Report extends AbstractDb
{
    /**
     * { @inheritdoc }
     */
    public function _construct()
    {
        $this->_init('bss_inventoryreport', 'report_id');
    }

    /**
     * @param string $currentTime
     * @param int $productId
     * @param string $productName
     * @param string $productSku
     * @param string $stockQtyAfter
     * @param int $qtyChange
     * @param string $stockStatus
     * @param string $user
     * @param string $note
     * @param int $customerId
     * @param int $incrementId
     * @return void
     */
    public function saveReport(
        $currentTime,
        $productId,
        $productName,
        $productSku,
        $stockQtyAfter,
        $qtyChange,
        $stockStatus,
        $user,
        $note,
        $customerId,
        $incrementId
    ) {
        $connection = $this->getConnection();
        $bind = [
            'time' => $currentTime,
            'product_id' => $productId,
            'product_name' => $productName,
            'product_sku' => $productSku,
            'qty_after' => $stockQtyAfter,
            'qty_change' => $qtyChange,
            'stock_status' => $stockStatus,
            'user' => $user,
            'note' => $note,
            'customer_id' => $customerId,
            'order_increment_id'=> $incrementId
        ];
        $connection->insert($this->getTable('bss_inventoryreport'), $bind);
    }

    /**
     * @param array $data
     * @return $this
     */
    public function saveMultipleData($data)
    {
        $this->getConnection()->insertMultiple($this->getTable('bss_inventoryreport'), $data);
        return $this;
    }

    /**
     * Update product by product sku after save product
     * @param string $productSku
     * @param int $productId
     * @param string $stockStatus
     * @return void
     */
    public function updateProductId($productSku, $productId, $stockStatus)
    {
        $connection = $this->getConnection();
        $where = ['product_sku IN (?)' => $productSku];
        $connection->update(
            $this->getTable('bss_inventoryreport'),
            [
                'product_id' => $productId,
                'stock_status' => $stockStatus
            ],
            $where
        );
    }

    /**
     * Update Import Product
     * @param string $productSku
     * @param string $currentTime
     * @param int $productId
     * @param string $note
     * @param string $productName
     * @param string $stockQtyAfter
     * @param string $stockStatus
     * @param string $user
     * @return void
     */
    public function updateImportProduct(
        $productSku,
        $currentTime,
        $productId,
        $note,
        $productName,
        $stockQtyAfter,
        $stockStatus,
        $user
    ) {
        $connection = $this->getConnection();
        $where = ['product_sku IN (?)' => $productSku,'note In (?)' =>$note];
        $connection->update(
            $this->getTable('bss_inventoryreport'),
            [
                'product_id' => $productId,
                'time' => $currentTime,
                'product_name' => $productName,
                'qty_after' => $stockQtyAfter,
                'stock_status' => $stockStatus,
                'user' => $user
            ],
            $where);
    }
}
