<?php
/**
 * BSS Commerce Co.
 *
 * NOTICE OF LICENSE
 *
 * @category   BSS
 * @package    Bss_InventoryReport
 * @author     Extension Team
 * @copyright  Copyright (c) 2018-2019 BSS Commerce Co. ( http://bsscommerce.com )
 * @license    http://bsscommerce.com/Bss-Commerce-License.txt
 */

namespace Bss\InventoryReport\Observer;

use Bss\InventoryReport\Model\ResourceModel\Report;
use Exception;
use Magento\CatalogInventory\Api\StockRegistryInterface;
use Magento\CatalogInventory\Model\Stock\Status;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Exception\CouldNotSaveException;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\Registry;

class EditorInlineSaveAfter implements ObserverInterface
{
    /**
     * @var Registry
     */
    protected $coreRegistry;

    /**
     * @var Report
     */
    protected $reportResource;

    /**
     * @var RequestInterface
     */
    protected $request;

    /**
     * @var StockRegistryInterface
     */
    protected $stockRegistry;

    /**
     * EditorInlineSaveAfter constructor.
     * @param Registry $coreRegistry
     * @param Report $reportResource
     * @param RequestInterface $request
     * @param StockRegistryInterface $stockRegistry
     */
    public function __construct(
        Registry $coreRegistry,
        Report $reportResource,
        RequestInterface $request,
        StockRegistryInterface $stockRegistry
    ) {
        $this->coreRegistry = $coreRegistry;
        $this->reportResource = $reportResource;
        $this->request = $request;
        $this->stockRegistry = $stockRegistry;
    }

    /**
     * @param Observer $observer
     * @return $this|void
     * @throws CouldNotSaveException
     */
    public function execute(Observer $observer)
    {
        $dataPost = $this->coreRegistry->registry(EditorInlineSaveBefore::KEY_DATA_INLINE_EDIT_SAVE_BEFORE);
        try {
            if ($this->isValidArray($dataPost)) {
                $dataProgress = [];
                $products = $observer->getData('products');
                foreach ($products as $product) {
                    if ($this->proceedDataPost($dataPost, $product)) {
                        $dataProgress[] = $this->proceedDataPost($dataPost, $product);
                    }
                }
                if ($this->isValidArray($dataProgress)) {
                    $this->reportResource->saveMultipleData($dataProgress);
                }
            }
        } catch (Exception $exception) {
            throw new CouldNotSaveException(
                __('Something went wrong while processing inventory report. Please see log.')
            );
        }
        $this->coreRegistry->unregister(EditorInlineSaveBefore::KEY_DATA_INLINE_EDIT_SAVE_BEFORE);
        return $this;
    }

    /**
     * @param array $arr
     * @return bool
     */
    private function isValidArray($arr)
    {
        return is_array($arr) && !empty($arr);
    }

    /**
     * @param array $dataPost
     * @param string|int $postItem
     * @return array|bool
     * @throws NoSuchEntityException
     */
    protected function proceedDataPost($dataPost, $postItem)
    {
        if (!isset($dataPost[$postItem]) ||
            !isset($dataPost[$postItem]['product_sku'])) {
            return false;
        }

        $itemData = $dataPost[$postItem];
        $stockStatus = Status::STATUS_OUT_OF_STOCK;

        $productStock = $this->stockRegistry->getStockItemBySku($itemData['product_sku']);
        if ($productStock && $productStock->getIsInStock()) {
            $stockStatus = $productStock->getIsInStock();
        }
        $tempData = array_merge_recursive($itemData, ['stock_status' => $stockStatus]);
        return $tempData;
    }
}
