<?php
/**
 * BSS Commerce Co.
 *
 * NOTICE OF LICENSE
 *
 * @category   BSS
 * @package    Bss_InventoryReport
 * @author     Extension Team
 * @copyright  Copyright (c) 2018-2019 BSS Commerce Co. ( http://bsscommerce.com )
 * @license    http://bsscommerce.com/Bss-Commerce-License.txt
 */
namespace Bss\InventoryReport\Plugin\Attribute;

use Magento\Catalog\Controller\Adminhtml\Product\Action\Attribute\Edit;
use Magento\Catalog\Helper\Product\Edit\Action\Attribute;
use Magento\CatalogInventory\Api\StockRegistryInterface;

class MassQtyBeforeChange
{
    /**
     * @var Attribute
     */
    private $attributeHelper;

    /**
     * @var \Magento\Backend\Model\Session
     */
    private $backendSession;

    /**
     * @var StockRegistryInterface
     */
    private $stockRegistry;

    /**
     * MassQtyBeforeChange constructor.
     * @param Attribute $attributeHelper
     * @param \Magento\Backend\Model\Session $backendSession
     * @param StockRegistryInterface $stockRegistry
     */
    public function __construct(
        Attribute $attributeHelper,
        \Magento\Backend\Model\Session $backendSession,
        StockRegistryInterface $stockRegistry
    ) {
        $this->attributeHelper = $attributeHelper;
        $this->backendSession = $backendSession;
        $this->stockRegistry = $stockRegistry;
    }

    /**
     * After go to edit product attribute page
     *
     * @param Edit $subject
     * @param array $result
     * @return array
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function afterExecute(
        Edit $subject,
        $result
    ) {
        /** @var \Magento\Framework\App\RequestInterface $request */
        $productIds = $this->attributeHelper->getProductIds();
        if (is_array($productIds) && !empty($productIds)) {
            $storeId = $this->attributeHelper->getSelectedStoreId();
            $websiteId = $this->attributeHelper->getStoreWebsiteId($storeId);
            $data = $this->storageQtyBefore($productIds, $websiteId);
            $this->backendSession->setBssStorageQtyBefore($data);
        }
        return $result;
    }

    /**
     * Storage Qty Before Update by product Id
     *
     * @param array $productIds
     * @param int $websiteId
     * @return array
     */
    private function storageQtyBefore($productIds, $websiteId)
    {
        $data = [];
        foreach ($productIds as $productId) {
            $stockItemDo = $this->stockRegistry->getStockItem($productId, $websiteId);
            $data[$productId] = $stockItemDo->getQty();
        }
        return $data;
    }
}
