<?php
/**
 * BSS Commerce Co.
 *
 * NOTICE OF LICENSE
 *
 * @category   BSS
 * @package    Bss_InventoryReport
 * @author     Extension Team
 * @copyright  Copyright (c) 2018-2019 BSS Commerce Co. ( http://bsscommerce.com )
 * @license    http://bsscommerce.com/Bss-Commerce-License.txt
 */

namespace Bss\InventoryReport\Plugin\Model;

use Bss\InventoryReport\Helper\InventoryData as InventoryDataHelper;
use Bss\InventoryReport\Model\MultiInventorySource\MsiObjectManagement;
use Bss\InventoryReport\Model\MultiInventorySource\StockAndSourceProcessor;
use Bss\InventoryReport\Model\ReportFactory;
use Magento\Catalog\Api\ProductRepositoryInterface;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\Stdlib\DateTime\TimezoneInterface;
use Magento\InventoryCatalog\Model\ResourceModel\BulkSourceUnassign;

class ProcessUnassgin
{
    /**
     * @var ReportFactory
     */
    protected $reportFactory;

    /**
     * @var MsiObjectManagement
     */
    protected $msiObjectManagement;

    /**
     * @var StockAndSourceProcessor
     */
    protected $stockAndSourceProcessor;

    /**
     * @var ProductRepositoryInterface
     */
    protected $productRepository;

    /**
     * @var TimezoneInterface
     */
    protected $timezone;

    /**
     * @var InventoryDataHelper
     */
    protected $inventoryDataHelper;

    /**
     * ProcessUnassgin constructor.
     * @param ReportFactory $reportFactory
     * @param MsiObjectManagement $msiObjectManagement
     * @param StockAndSourceProcessor $stockAndSourceProcessor
     * @param ProductRepositoryInterface $productRepository
     * @param TimezoneInterface $timezone
     * @param InventoryDataHelper $inventoryDataHelper
     */
    public function __construct(
        ReportFactory $reportFactory,
        MsiObjectManagement $msiObjectManagement,
        StockAndSourceProcessor $stockAndSourceProcessor,
        ProductRepositoryInterface $productRepository,
        TimezoneInterface $timezone,
        InventoryDataHelper $inventoryDataHelper
    ) {
        $this->reportFactory = $reportFactory;
        $this->msiObjectManagement = $msiObjectManagement;
        $this->stockAndSourceProcessor = $stockAndSourceProcessor;
        $this->productRepository = $productRepository;
        $this->timezone = $timezone;
        $this->inventoryDataHelper = $inventoryDataHelper;
    }

    /**
     * Process save report while unassign source
     *
     * @param BulkSourceUnassign $subject
     * @param Closure $proceed
     * @param array $skus
     * @param array $sourceCodes
     * @return mixed
     * @throws NoSuchEntityException
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function aroundExecute(
        $subject,
        \Closure $proceed,
        array $skus,
        array $sourceCodes
    ) {

        if ($this->msiObjectManagement->isMsiEnabled()) {
            foreach ($sourceCodes as $sourceCode) {
                $this->processReport($sourceCode, $skus);
            }
        }
        return $proceed($skus, $sourceCodes);
    }

    /**
     * Save Report
     *
     * @param string $sourceCode
     * @param array $skus
     * @throws NoSuchEntityException
     */
    protected function processReport($sourceCode, $skus)
    {
        foreach ($skus as $sku) {
            $sourceItem = $this->stockAndSourceProcessor->getSourceItem($sku, $sourceCode);
            if ($sourceItem && $sourceItem->getQuantity() > 0) {
                $beforeQuantity = $sourceItem->getQuantity();
                $product = $this->productRepository->get($sku);
                $data['time'] = $this->timezone->date();
                $data['user'] = $this->inventoryDataHelper->getAdminName();
                $data['note'] = __('Bulk Unassign Source');
                $data['product_id'] = $product->getId();
                $data['product_name'] = $product->getName();
                $data['product_sku'] = $product->getSku();
                $data['qty_after'] = 0;
                $data['qty_change'] = 0 - $beforeQuantity;
                $data['stock_status'] = '';
                $data['source_code'] = $sourceCode;
                $this->reportFactory->create()->setData($data)->save();
            }
        }
    }
}
