<?php
/**
 * BSS Commerce Co.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the EULA
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://bsscommerce.com/Bss-Commerce-License.txt
 *
 * @category   BSS
 * @package    Bss_InventoryReport
 * @author     Extension Team
 * @copyright  Copyright (c) 2017-2018 BSS Commerce Co. ( http://bsscommerce.com )
 * @license    http://bsscommerce.com/Bss-Commerce-License.txt
 */

namespace Bss\InventoryReport\Plugin\Model;

use Bss\InventoryReport\Helper\InventoryData as InventoryDataHelper;
use Bss\InventoryReport\Model\MultiInventorySource\MsiObjectManagement;
use Bss\InventoryReport\Model\ResourceModel\Report as InventoryResourceReport;
use Magento\Catalog\Api\ProductRepositoryInterface;
use Magento\CatalogInventory\Api\Data\StockItemInterface;
use Magento\CatalogInventory\Api\StockRegistryInterface;
use Magento\Framework\Registry;
use Magento\Framework\Stdlib\DateTime\DateTime;
use Magento\CatalogInventory\Model\StockRegistry as CatalogStockRegistry;

class StockRegistry
{
    /**
     * @var DateTime
     */
    protected $date;

    /**
     * @var StockRegistryInterface
     */
    protected $stockRegistry;

    /**
     * @var InventoryResourceReport
     */
    protected $inventoryResourceReport;

    /**
     * @var ProductRepositoryInterface
     */
    protected $productRepository;

    /**
     * @var Registry
     */
    protected $registry;

    /**
     * @var MsiObjectManagement
     */
    protected $msiObjectManagement;

    /**
     * @var InventoryDataHelper
     */
    protected $inventoryDataHelper;

    /**
     * StockRegistry constructor.
     * @param DateTime $date
     * @param StockRegistryInterface $stockRegistry
     * @param InventoryResourceReport $inventoryResourceReport
     * @param ProductRepositoryInterface $productRepository
     * @param Registry $registry
     * @param MsiObjectManagement $msiObjectManagement
     * @param InventoryDataHelper $inventoryDataHelper
     */
    public function __construct(
        DateTime $date,
        StockRegistryInterface $stockRegistry,
        InventoryResourceReport $inventoryResourceReport,
        ProductRepositoryInterface $productRepository,
        Registry $registry,
        MsiObjectManagement $msiObjectManagement,
        InventoryDataHelper $inventoryDataHelper
    ) {
        $this->date = $date;
        $this->stockRegistry = $stockRegistry;
        $this->inventoryResourceReport = $inventoryResourceReport;
        $this->productRepository = $productRepository;
        $this->registry = $registry;
        $this->msiObjectManagement = $msiObjectManagement;
        $this->inventoryDataHelper = $inventoryDataHelper;
    }

    /**
     * @param CatalogStockRegistry $subject
     * @param Closure $proceed
     * @param $productSku
     * @param StockItemInterface $stockItem
     * @return mixed
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function aroundUpdateStockItemBySku(
        CatalogStockRegistry $subject,
        \Closure $proceed,
        $productSku,
        StockItemInterface $stockItem
    ) {
        // Only process this if MSI isn't enabled
        if (!$this->msiObjectManagement->isMsiEnabled()) {
            if (!$this->registry->registry('admin_save_product')) {
                $currentTime = $this->date->gmtDate();
                $product = $this->productRepository->get($productSku);
                $productId = $product->getId();
                $productName = $product->getName();

                $stockItems = $this->stockRegistry->getStockItem($productId);
                $stockQty = $stockItems->getQty();
                $stockQtyAfter = $stockItem->getQty();
                $qtyChange = (int)$stockQtyAfter - (int)$stockQty;
                $stockStatus = $stockItems->getIsInStock();

                $user = $this->inventoryDataHelper->getAdminName();
                $stockStatus = $stockStatus == 1 && $stockQtyAfter > 0 ? 1 : 0;
                $note = __('Change stock by REST API');
                if ($qtyChange) {
                    $qtyChange = $this->getQtyChange($qtyChange);
                    $this->inventoryResourceReport->saveReport(
                        $currentTime,
                        $productId,
                        $productName,
                        $productSku,
                        $stockQtyAfter,
                        $qtyChange,
                        $stockStatus,
                        $user,
                        $note,
                        null,
                        null
                    );
                }
            }
            return $proceed($productSku, $stockItem);
        }
        return $proceed($productSku, $stockItem);
    }

    /**
     * @param int|string|float $qtyChange
     * @return string
     */
    protected function getQtyChange($qtyChange)
    {
        if ($qtyChange > 0) {
            return $qtyChange;
        }
        $qtyChange = abs($qtyChange);
        return 0 - $qtyChange;
    }
}
