<?php
/**
 * BSS Commerce Co.
 *
 * NOTICE OF LICENSE
 *
 * @category   BSS
 * @package    Bss_InventoryReport
 * @author     Extension Team
 * @copyright  Copyright (c) 2018-2019 BSS Commerce Co. ( http://bsscommerce.com )
 * @license    http://bsscommerce.com/Bss-Commerce-License.txt
 */
namespace Bss\InventoryReport\Setup;

use Magento\Framework\DB\Adapter\AdapterInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;
use Magento\Framework\Setup\UpgradeSchemaInterface;

class UpgradeSchema implements UpgradeSchemaInterface
{
    /**
     * Update New Column
     *
     * @param SchemaSetupInterface $setup
     * @param ModuleContextInterface $context
     * @throws \Zend_Db_Exception
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function upgrade(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $setup->startSetup();
        $bssInventoryTable = $setup->getTable('bss_inventoryreport');
        $connection = $setup->getConnection();
        if ($setup->getConnection()->isTableExists($bssInventoryTable) == true) {
            $connection->addColumn(
                $bssInventoryTable,
                'source_code',
                [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Source Name'
                ]
            );
        }
        if (version_compare($context->getVersion(), '1.1.2', '<')) {
            if ($setup->getConnection()->isTableExists($bssInventoryTable) == true) {
                $connection->addColumn(
                    $bssInventoryTable,
                    'saleable_qty',
                    [
                       'type' => \Magento\Framework\DB\Ddl\Table::TYPE_DECIMAL,
                       'length' => '12,2',
                       'nullable' => true,
                       'comment' => 'Saleable Quantity'
                    ]
                );
                $connection->addColumn(
                    $bssInventoryTable,
                    'saleable_qty_change',
                    [
                       'type' => \Magento\Framework\DB\Ddl\Table::TYPE_DECIMAL,
                       'length' => '12,2',
                       'nullable' => true,
                       'comment' => 'Saleable Quantity Change'
                    ]
                );
                $connection->addColumn(
                    $bssInventoryTable,
                    'stock_id',
                    [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        'length' => 10,
                        'nullable' => true,
                        'comment' => 'Stock Id'
                    ]
                );
                $connection->addColumn(
                    $bssInventoryTable,
                    'order_increment_id',
                    [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        'length' => 32,
                        'nullable' => true,
                        'comment' => 'Order Increment ID'
                    ]
                );
                $connection->addColumn(
                    $bssInventoryTable,
                    'customer_id',
                    [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        'length' => 10,
                        'nullable' => true,
                        'comment' => 'Customer Id'
                    ]
                );
                $connection->modifyColumn(
                    $bssInventoryTable,
                    'qty_change',
                    [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_DECIMAL,
                        'length' => '12,2',
                    ]
                );
                $connection->modifyColumn(
                    $bssInventoryTable,
                    'qty_after',
                    [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_DECIMAL,
                        'length' => '12,2',
                    ]
                );
                $connection->addColumn(
                    $bssInventoryTable,
                    'invoice_entity_id',
                    [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        'length' => 32,
                        'nullable' => true,
                        'comment' => 'Invoice ID'
                    ]
                );
            }
        }

        $this->mapIndexTable($context, $setup, $bssInventoryTable);

        $setup->endSetup();
    }

    /**
     * Add index full text search
     *
     * @param ModuleContextInterface $context
     * @param SchemaSetupInterface $setup
     * @param string $bssInventoryTable
     */
    private function mapIndexTable($context, $setup, $bssInventoryTable)
    {
        if (version_compare($context->getVersion(), '1.1.3', '<')) {
            if ($setup->getConnection()->isTableExists($bssInventoryTable) == true) {
                $connection = $setup->getConnection();
                $connection->addIndex(
                    $bssInventoryTable,
                    $setup->getIdxName(
                        $bssInventoryTable,
                        [
                            'product_id','stock_status', 'note', 'user',
                            'product_name', 'product_sku', 'source_code'
                        ],
                        AdapterInterface::INDEX_TYPE_FULLTEXT
                    ),
                    [
                        'product_id', 'stock_status', 'note', 'user',
                        'product_name', 'product_sku', 'source_code'
                    ],
                    AdapterInterface::INDEX_TYPE_FULLTEXT
                );
            }
        }
    }
}
