<?php
/**
 * BSS Commerce Co.
 *
 * NOTICE OF LICENSE
 *
 * @category   BSS
 * @package    Bss_InventoryReport
 * @author     Extension Team
 * @copyright  Copyright (c) 2018-2019 BSS Commerce Co. ( http://bsscommerce.com )
 * @license    http://bsscommerce.com/Bss-Commerce-License.txt
 */
namespace Bss\InventoryReport\Ui\Component\Listing\Column;

use Magento\Backend\Helper\Data;
use Magento\Framework\View\Element\UiComponent\ContextInterface;
use Magento\Framework\View\Element\UiComponentFactory;
use Magento\Sales\Api\Data\OrderInterface;

class ReportActions extends \Magento\Ui\Component\Listing\Columns\Column
{
    /**
     * @var Data
     */
    protected $adminhtmlData;

    /**
     * @var OrderInterface
     */
    protected $orderIterface;

    /**
     * ReportActions constructor.
     * @param ContextInterface $context
     * @param UiComponentFactory $uiComponentFactory
     * @param Data $adminhtmlData
     * @param OrderInterface $orderIterface
     * @param array $components
     * @param array $data
     */
    public function __construct(
        ContextInterface $context,
        UiComponentFactory $uiComponentFactory,
        Data $adminhtmlData,
        OrderInterface $orderIterface,
        array $components = [],
        array $data = []
    ) {
        $this->adminhtmlData = $adminhtmlData;
        $this->orderIterface = $orderIterface;
        parent::__construct($context, $uiComponentFactory, $components, $data);
    }
    /**
     * Prepare Data Source
     *
     * @param array $dataSource
     * @return array
     */
    public function prepareDataSource(array $dataSource)
    {
        $urlLinkArray = [];
        $urlLinkArray = $this->getArrayList($urlLinkArray);

        if (isset($dataSource['data']['items'])) {
            foreach ($dataSource['data']['items'] as & $item) {
                if (isset($item['report_id'])) {
                    foreach ($urlLinkArray as $key => $value) {
                        if (isset($item[$key])) {
                            $this->getOrderKey($item, $key);
                            $requestUrl = $this->adminhtmlData->getUrl(
                                $value['url'],
                                [$value['param_id'] => $item[$key]]
                            );
                            $item[$this->getData('name')] = [
                                'view' => [
                                    'href' => $requestUrl,
                                    'label' => __($value['label'])
                                ],
                            ];
                        }
                    }
                }
            }
        }
        return $dataSource;
    }

    /**
     * Get array list url backend
     *
     * @param array $arrayList
     * @return array
     */
    public function getArrayList($arrayList)
    {
        $arrayList['shipment_entity_id'] = [
            'url' => 'sales/shipment/view',
            'param_id' => 'shipment_id',
            'label' => 'View Shipment'
        ];
        $arrayList['credit_entity_id'] = [
            'url' => 'sales/creditmemo/view',
            'param_id' => 'creditmemo_id',
            'label' => 'View Credit'
        ];
        $arrayList['order_increment_id'] = [
            'url' => 'sales/order/view',
            'param_id' => 'order_id',
            'label' => 'View Order'
        ];
        $arrayList['invoice_entity_id'] = [
            'url' => 'sales/invoice/view',
            'param_id' => 'invoice_id',
            'label' => 'View Invoice'
        ];
        return $arrayList;
    }

    /**
     * @param array $item
     * @param string $key
     */
    protected function getOrderKey(&$item, $key)
    {
        if ($key == 'order_increment_id') {
            $item[$key] = $this->orderIterface->loadByIncrementId($item[$key])->getId();
        }
    }
}
